@@ -1,7 +1,6 @@
 """Response Schema Generator Module for a Multiple Choice Question"""
 import copy
 import itertools
-
 from django_workflow_system.utils import RESPONSE_SCHEMA
 
 
@@ -29,9 +28,12 @@ def get_response_schema(workflow_step_user_input):
         ] = workflow_step_user_input.type.json_schema["properties"]["correctInput"][
             "type"
         ]
-        response_schema["properties"]["userInput"]["enum"] = [
+
+        response_schema["properties"]["userInput"][
+            "enum"
+        ] = fetch_all_combinations_unordered(
             workflow_step_user_input.specification["correctInput"]
-        ]
+        )
 
     elif (
         workflow_step_user_input.specification["meta"]["inputRequired"]
@@ -86,3 +88,20 @@ def fetch_all_combinations(workflow_step_user_input):
             )
         ]
     return all_combos
+
+
+def fetch_all_combinations_unordered(correct_answer):
+    """
+    Fetch all possible combinations of a multi choice question, where order does not matter.
+
+    Args:
+        workflow_step_user_input (WorkflowStepUserInput): The Workflow correct input.
+
+    Returns:
+        list: All possible combinations of available answers.
+    """
+
+    combos = itertools.permutations(correct_answer)
+    all_combos = [list(combo) for combo in combos]
+
+    return all_combos
